# Generated by roxygen2: do not edit by hand

S3method(as.data.frame,shrinkr_fit)
S3method(as.data.frame,shrinkr_mixture)
S3method(as.data.frame,shrinkr_prior_pred)
S3method(as_draws_df,shrinkr_fit)
S3method(plot,shrinkr_fit)
S3method(plot,shrinkr_mixture)
S3method(plot,shrinkr_prior_contrasts)
S3method(plot,shrinkr_prior_pred)
S3method(print,shrinkr_fit)
S3method(print,shrinkr_mixture)
S3method(print,shrinkr_prior_contrasts)
S3method(print,shrinkr_prior_pred)
S3method(print,summary.shrinkr_mixture)
S3method(print,summary.shrinkr_prior_pred)
S3method(summary,shrinkr_fit)
S3method(summary,shrinkr_mixture)
S3method(summary,shrinkr_prior_pred)
export(extract_mu_tau)
export(extract_theta)
export(fit_mixture)
export(prior_mixture)
export(prior_pairwise_differences)
export(prior_spike_slab)
export(sample_prior_predictive)
export(shrink)
export(summarise_mu_tau)
export(summarise_theta)
export(summarize_mu_tau)
export(summarize_theta)
export(theta_contrasts)
import(Rcpp)
import(mclust)
import(methods)
import(rstan)
importFrom(RcppParallel,RcppParallelLibs)
importFrom(distributional,parameters)
importFrom(posterior,as_draws_df)
importFrom(rstantools,rstan_config)
importFrom(stats,complete.cases)
importFrom(stats,cov)
importFrom(stats,density)
importFrom(stats,dnorm)
importFrom(stats,pnorm)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,rnorm)
importFrom(stats,sd)
importFrom(stats,uniroot)
importFrom(stats,var)
useDynLib(shrinkr, .registration = TRUE)
